Skip to contents

This function validates and adds a Res object (Res) to a Userm object (Userm). It checks whether the Res object has a valid ID, matching detectors, and properly structured matrices (interceptMtx and slopMtx). If all checks pass, the Res object is added to the Userm$Res list.

Usage

AddRes2Userm(Res, Userm)

Arguments

Res

A Res object.

Userm

A Userm object, generated with CreateUserm function.

Value

The updated Userm object with the new Res object added.

Examples

if (FALSE) { # \dontrun{
Res <- CreateRes(id, R, A)
Userm <- CreateUserm(A)
Userm <- AddRes2Userm(Res, Userm)
} # }