This function adds or updates scaling parameters for a given fluorophore in a userm object.
It validates the input fluor name, scaling method, and numeric parameters, then stores them in the
Scale_df field of the Userm object.
Arguments
- Userm
A userm object created by
CreateUserm, containing fluor and detector information.- fluor
A character string specifying the fluorophore to update.
- min
A numeric value specifying the minimum intensity threshold. Default is -100.
- max
A numeric value specifying the maximum intensity threshold. Default is 1000.
- scale
A character string specifying the scaling method. Must be one of
"Linear","Log10", or"Arcsinh". Default is"Linear".- cofactor
A positive numeric value used for scaling (only used for
"Arcsinh"). Default is 10.