Launch an interactive Shiny app to explore predicted spread
Source:R/PredOneSpread.R
PredOneSpread.RdThis function launches a Shiny application that allows users to interactively explore the predicted spread
of unmixed signals based on a given userm object (Userm) and a selected population.
The app provides multiple tabs for visualizing the unmixing matrix, prediction plots, slope and intercept matrices,
and exporting results.
Arguments
- Userm
A userm object created by
CreateUserm, containing unmixing matrix, detector and fluor information, and intensity data.- population_id
A character string specifying the column name in
Userm$Intensity_mtxrepresenting the population to be visualized.